# :octicons-code-24: - Development

This section is intended to all developers who want to contribute to the project by:

- fixing one or more bugs
- improving the library
- creating a new `Interaction`

Depending on the scope, different actions should be taken into consideration.

Since you are reading this section, it could mean that you want to contribute to the project by improving the library, for this reason I want to say... **Thank You**!

<div class="grid cards" markdown>

-   :material-new-box:{ .lg .middle } **New `Interaction`**

    ---

    Extend the library by implementing an `Interaction`.

    [:octicons-arrow-right-24: Reference](new-interaction.md)

-   :material-bug:{ .lg .middle } **Bug & Improvements**

    ---

    Correct a bug or improve the library by proposing new ideas.

    [:octicons-arrow-right-24: Reference](bugs-improvements.md)

-   :material-test-tube:{ .lg .middle } **Testing**

    ---

    Understand how the tests are managed inside the library.

    [:octicons-arrow-right-24: Reference](testing.md)

-   :material-source-pull:{ .lg .middle } **Pull Requests**

    ---

    Prepare your code to be merged.

    [:octicons-arrow-right-24: Reference](pull-requests.md)

</div>

## Latest Library Version

To use locally the latest version of the library not yet released:

- clone or fork the repository
- activate the `python` environment you want to use
- navigate to the `root` folder of the library
- run the command `pip install -e .`

By using these commands, you will have the latest `cyhole` version of the library on the desired environment.

!!! note
    The **latest** version is under development, and for this reason it could be unstable or having bugs.
